@@ -242,14 +242,32 @@ class AccountClient(BaseClient):
             exc_cls, exc_msg = self._get_exception(headers=res.headers, status_code=res.status_code, data=res.content)
             raise exc_cls(exc_msg)
 
-    def get_account_limits(self, account):
+    def get_account_limits(self, account, rse_expression, locality):
         """
-        List the account rse limits of this account.
+        Return the correct account limits for the given locality.
 
-        :param account: The account name.
+        :param account:        The account name.
+        :param rse_expression: Valid RSE expression
+        :param locality:       The scope of the account limit. 'local' or 'global'.
         """
 
-        path = '/'.join([self.ACCOUNTS_BASEURL, account, 'limits'])
+        if locality == 'local':
+            return self.get_local_account_limit(account, rse_expression)
+        elif locality == 'global':
+            return self.get_global_account_limit(account, rse_expression)
+        else:
+            from rucio.common.exception import UnsupportedOperation
+            raise UnsupportedOperation('The provided locality (%s) for the account limit was invalid' % locality)
+
+    def get_global_account_limit(self, account, rse_expression):
+        """
+        List the account limit for the specific RSE expression.
+
+        :param account:        The account name.
+        :param rse_expression: The rse expression.
+        """
+
+        path = '/'.join([self.ACCOUNTS_BASEURL, account, 'limits', 'global', rse_expression])
         url = build_url(choice(self.list_hosts), path=path)
         res = self._send_request(url, type='GET')
         if res.status_code == codes.ok:
@@ -257,7 +275,37 @@ class AccountClient(BaseClient):
         exc_cls, exc_msg = self._get_exception(headers=res.headers, status_code=res.status_code, data=res.content)
         raise exc_cls(exc_msg)
 
-    def get_account_limit(self, account, rse):
+    def get_global_account_limits(self, account):
+        """
+        List all RSE expression limits of this account.
+
+        :param account: The account name.
+        """
+
+        path = '/'.join([self.ACCOUNTS_BASEURL, account, 'limits', 'global'])
+        url = build_url(choice(self.list_hosts), path=path)
+        res = self._send_request(url, type='GET')
+        if res.status_code == codes.ok:
+            return next(self._load_json_data(res))
+        exc_cls, exc_msg = self._get_exception(headers=res.headers, status_code=res.status_code, data=res.content)
+        raise exc_cls(exc_msg)
+
+    def get_local_account_limits(self, account):
+        """
+        List the account rse limits of this account.
+
+        :param account: The account name.
+        """
+
+        path = '/'.join([self.ACCOUNTS_BASEURL, account, 'limits', 'local'])
+        url = build_url(choice(self.list_hosts), path=path)
+        res = self._send_request(url, type='GET')
+        if res.status_code == codes.ok:
+            return next(self._load_json_data(res))
+        exc_cls, exc_msg = self._get_exception(headers=res.headers, status_code=res.status_code, data=res.content)
+        raise exc_cls(exc_msg)
+
+    def get_local_account_limit(self, account, rse):
         """
         List the account rse limits of this account for the specific rse.
 
@@ -265,7 +313,7 @@ class AccountClient(BaseClient):
         :param rse:     The rse name.
         """
 
-        path = '/'.join([self.ACCOUNTS_BASEURL, account, 'limits', rse])
+        path = '/'.join([self.ACCOUNTS_BASEURL, account, 'limits', 'local', rse])
         url = build_url(choice(self.list_hosts), path=path)
         res = self._send_request(url, type='GET')
         if res.status_code == codes.ok:
@@ -273,7 +321,7 @@ class AccountClient(BaseClient):
         exc_cls, exc_msg = self._get_exception(headers=res.headers, status_code=res.status_code, data=res.content)
         raise exc_cls(exc_msg)
 
-    def get_account_usage(self, account, rse=None):
+    def get_local_account_usage(self, account, rse=None):
         """
         List the account usage for one or all rses of this account.
 
@@ -281,9 +329,28 @@ class AccountClient(BaseClient):
         :param rse:     The rse name.
         """
         if rse:
-            path = '/'.join([self.ACCOUNTS_BASEURL, account, 'usage', rse])
+            path = '/'.join([self.ACCOUNTS_BASEURL, account, 'usage', 'local', rse])
         else:
-            path = '/'.join([self.ACCOUNTS_BASEURL, account, 'usage/'])
+            path = '/'.join([self.ACCOUNTS_BASEURL, account, 'usage', 'local'])
+        url = build_url(choice(self.list_hosts), path=path)
+        res = self._send_request(url, type='GET')
+        if res.status_code == codes.ok:
+            return self._load_json_data(res)
+        else:
+            exc_cls, exc_msg = self._get_exception(headers=res.headers, status_code=res.status_code, data=res.content)
+            raise exc_cls(exc_msg)
+
+    def get_global_account_usage(self, account, rse_expression=None):
+        """
+        List the account usage for one or all RSE expressions of this account.
+
+        :param account:        The account name.
+        :param rse_expression: The rse expression.
+        """
+        if rse_expression:
+            path = '/'.join([self.ACCOUNTS_BASEURL, account, 'usage', 'global', rse_expression])
+        else:
+            path = '/'.join([self.ACCOUNTS_BASEURL, account, 'usage', 'global'])
         url = build_url(choice(self.list_hosts), path=path)
         res = self._send_request(url, type='GET')
         if res.status_code == codes.ok:
