@@ -16,7 +16,7 @@
 # - Ralph Vigne <ralph.vigne@cern.ch>, 2012-2014
 # - Vincent Garonne <vgaronne@gmail.com>, 2012-2016
 # - Mario Lassnig <mario.lassnig@cern.ch>, 2013-2019
-# - Cedric Serfon <cedric.serfon@cern.ch>, 2013-2016
+# - Cedric Serfon <cedric.serfon@cern.ch>, 2013-2020
 # - Wen Guan <wguan.icedew@gmail.com>, 2014-2017
 # - Cheng-Hsi Chao <cheng-hsi.chao@cern.ch>, 2014
 # - Tobias Wegner <twegner@cern.ch>, 2017
@@ -26,9 +26,6 @@
 # - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2019
 # - James Clark <james.clark@physics.gatech.edu>, 2019
 # - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
-# - Eli Chadwick, <eli.chadwick@stfc.ac.uk>, 2020
-# - Luca Scotto Lavina, <scotto@lpnhe.in2p3.fr>, 2021
-# - Thomas Beermann, <thomas.beermann@cern.ch>, 2021
 #
 # PY3K COMPATIBLE
 
@@ -156,6 +153,28 @@ class RSEDeterministicTranslation(object):
             scope = scope.replace('.', '/')
         return '%s/%s' % (scope, name)
 
+    @staticmethod
+    def __belleii(scope, name, rse, rse_attrs, protocol_attrs):
+        """
+        Given a LFN, convert it directly to a path using the mapping:
+
+            path -> path
+        This is valid only for the belleii convention where the scope can be determined
+        from the LFN using a determinitic function.
+
+        :param scope: Scope of the LFN.
+        :param name: File name of the LFN.
+        :param rse: RSE for PFN (ignored)
+        :param rse_attrs: RSE attributes for PFN (ignored)
+        :param protocol_attrs: RSE protocol attributes for PFN (ignored)
+        :returns: Path for use in the PFN generation.
+        """
+        del scope
+        del rse
+        del rse_attrs
+        del protocol_attrs
+        return name
+
     @staticmethod
     def __ligo(scope, name, rse, rse_attrs, protocol_attrs):
         """
@@ -177,24 +196,6 @@ class RSEDeterministicTranslation(object):
         from ligo_rucio import lfn2pfn as ligo_lfn2pfn  # pylint: disable=import-error
         return ligo_lfn2pfn.ligo_lab(scope, name, None, None, None)
 
-    @staticmethod
-    def __xenon(scope, name, rse, rse_attrs, protocol_attrs):
-        """
-        Given a LFN, turn it into a two level sub-directory structure based on the scope
-        plus a third level based on the name
-        :param scope: Scope of the LFN.
-        :param name: File name of the LFN.
-        :param rse: RSE for PFN (ignored)
-        :param rse_attrs: RSE attributes for PFN (ignored)
-        :param protocol_attrs: RSE protocol attributes for PFN (ignored)
-        :returns: Path for use in the PFN generation.
-        """
-        del rse
-        del rse_attrs
-        del protocol_attrs
-
-        return '%s/%s/%s/%s' % (scope[0:7], scope[4:len(scope)], name.split('-')[0] + "-" + name.split('-')[1], name)
-
     @classmethod
     def _module_init_(cls):
         """
@@ -203,7 +204,7 @@ class RSEDeterministicTranslation(object):
         cls.register(cls.__hash, "hash")
         cls.register(cls.__identity, "identity")
         cls.register(cls.__ligo, "ligo")
-        cls.register(cls.__xenon, "xenon")
+        cls.register(cls.__belleii, "belleii")
         policy_module = None
         try:
             policy_module = config.config_get('policy', 'lfn2pfn_module')
