@@ -1,40 +1,54 @@
-# Copyright European Organization for Nuclear Research (CERN)
+# Copyright 2012-2019 CERN for the benefit of the ATLAS collaboration.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
-# You may not use this file except in compliance with the License.
-# You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 #
 # Authors:
-# - Vincent Garonne, <vincent.garonne@cern.ch>, 2012-2013
-# - Thomas Beermann, <thomas.beermann@cern.ch>, 2012
-# - Mario Lassnig, <mario.lassnig@cern.ch>, 2014
+# - Vincent Garonne <vgaronne@gmail.com>, 2012-2017
+# - Thomas Beermann <thomas.beermann@cern.ch>, 2012
+# - Mario Lassnig <mario.lassnig@cern.ch>, 2012-2019
+# - Angelos Molfetas <Angelos.Molfetas@cern.ch>, 2012
+# - Martin Barisits <martin.barisits@cern.ch>, 2014
+# - Cedric Serfon <cedric.serfon@cern.ch>, 2017
+# - Joaquin Bogado <jbogado@linti.unlp.edu.ar>, 2018
+
+from __future__ import print_function
 
-from getpass import getuser
 from os import remove
 
-
 from nose.tools import raises
 
 from rucio.client.baseclient import BaseClient
 from rucio.client.client import Client
 from rucio.common.config import config_get
+from rucio.common.utils import get_tmp_dir
 from rucio.common.exception import CannotAuthenticate, ClientProtocolNotSupported
 
 
-class TestBaseClient():
+class TestBaseClient(object):
+    """ To test Clients"""
 
     def setup(self):
+        '''
+        __init__
+        '''
         self.cacert = config_get('test', 'cacert')
         self.usercert = config_get('test', 'usercert')
-
+        self.userkey = config_get('test', 'userkey')
         try:
-            remove('/tmp/' + getuser() + '/.rucio_root/auth_token_root')
-        except OSError, e:
-            if e.args[0] != 2:
-                raise e
-
-    def tearDown(self):
-        pass
+            remove(get_tmp_dir() + '/.rucio_root/auth_token_root')
+        except OSError as error:
+            if error.args[0] != 2:
+                raise error
 
     def testUserpass(self):
         """ CLIENTS (BASECLIENT): authenticate with userpass."""
@@ -55,7 +69,8 @@ class TestBaseClient():
 
     def testx509(self):
         """ CLIENTS (BASECLIENT): authenticate with x509."""
-        creds = {'client_cert': self.usercert}
+        creds = {'client_cert': self.usercert,
+                 'client_key': self.userkey}
         BaseClient(account='root', ca_cert=self.cacert, auth_type='x509', creds=creds)
 
     @raises(CannotAuthenticate)
@@ -71,9 +86,13 @@ class TestBaseClient():
         BaseClient(rucio_host='localhost', auth_host='junk://localhost', account='root', auth_type='userpass', creds=creds)
 
 
-class TestRucioClients():
+class TestRucioClients(object):
+    """ To test Clients"""
 
     def setup(self):
+        '''
+        setup
+        '''
         self.cacert = config_get('test', 'cacert')
         self.marker = '$> '
 
@@ -81,6 +100,6 @@ class TestRucioClients():
         """ PING (CLIENT): Ping Rucio """
         creds = {'username': 'ddmlab', 'password': 'secret'}
 
-        c = Client(account='root', ca_cert=self.cacert, auth_type='userpass', creds=creds)
+        client = Client(account='root', ca_cert=self.cacert, auth_type='userpass', creds=creds)
 
-        print c.ping()
+        print(client.ping())
