@@ -1,12 +1,13 @@
-# Copyright European Organization for Nuclear Research (CERN)
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# You may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-# http://www.apache.org/licenses/LICENSE-2.0
-#
-# Authors:
-# - Vincent Garonne, <vincent.garonne@cern.ch>, 2013
+''' Copyright European Organization for Nuclear Research (CERN)
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ You may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Authors:
+ - Vincent Garonne, <vincent.garonne@cern.ch>, 2013
+'''
 
 from nose.tools import raises
 
@@ -15,7 +16,10 @@ from rucio.rse import rsemanager as mgr
 from rsemgr_api_test import MgrTestCases
 
 
-class TestRseMOCK():
+class TestRseMOCK(object):
+    '''
+    class TestRseMOCK
+    '''
     tmpdir = '/tmp/'
     user = None
     static_file = 'mock:///tmp/rucio_rse/file1'
@@ -30,22 +34,22 @@ class TestRseMOCK():
     @raises(exception.SourceNotFound)
     def test_get_mgr_SourceNotFound_multi(self):
         """MOCK (RSE/PROTOCOLS): Get multiple files from storage providing LFNs and PFNs (SourceNotFound)"""
-        for f in MgrTestCases.files_remote:
-            mgr.upload(mgr.get_rse_info(self.rse_id), [{'name': f, 'scope': 'user.%s' % self.user}, ])
+        for fichier in MgrTestCases.files_remote:
+            mgr.upload(mgr.get_rse_info(self.rse_id), [{'name': fichier, 'scope': 'user.%s' % self.user}, ])
         self.mtc.test_get_mgr_SourceNotFound_multi()
 
     @raises(exception.SourceNotFound)
     def test_get_mgr_SourceNotFound_single_lfn(self):
         """MOCK (RSE/PROTOCOLS): Get a single file from storage providing LFN (SourceNotFound)"""
-        for f in MgrTestCases.files_remote:
-            mgr.upload(mgr.get_rse_info(self.rse_id), [{'name': f, 'scope': 'user.%s' % self.user}, ])
+        for fichier in MgrTestCases.files_remote:
+            mgr.upload(mgr.get_rse_info(self.rse_id), [{'name': fichier, 'scope': 'user.%s' % self.user}, ])
         self.mtc.test_get_mgr_SourceNotFound_single_lfn()
 
     @raises(exception.SourceNotFound)
     def test_get_mgr_SourceNotFound_single_pfn(self):
         """MOCK (RSE/PROTOCOLS): Get a single file from storage providing PFN (SourceNotFound)"""
-        for f in MgrTestCases.files_remote:
-            mgr.upload(mgr.get_rse_info(self.rse_id), [{'name': f, 'scope': 'user.%s' % self.user}, ])
+        for fichier in MgrTestCases.files_remote:
+            mgr.upload(mgr.get_rse_info(self.rse_id), [{'name': fichier, 'scope': 'user.%s' % self.user}, ])
         self.mtc.test_get_mgr_SourceNotFound_single_pfn()
 
     # Mgr-Tests: PUT
@@ -56,14 +60,14 @@ class TestRseMOCK():
     # MGR-Tests: DELETE
     def test_delete_mgr_ok_multi(self):
         """MOCK (RSE/PROTOCOLS): Delete multiple files from storage (Success)"""
-        for f in MgrTestCases.files_remote:
-            mgr.upload(mgr.get_rse_info(self.rse_id), [{'name': f, 'scope': 'user.%s' % self.user}, ])
+        for fichier in MgrTestCases.files_remote:
+            mgr.upload(mgr.get_rse_info(self.rse_id), [{'name': fichier, 'scope': 'user.%s' % self.user}, ])
         self.mtc.test_delete_mgr_ok_multi()
 
     def test_delete_mgr_ok_single(self):
         """MOCK (RSE/PROTOCOLS): Delete a single file from storage (Success)"""
-        for f in MgrTestCases.files_remote:
-            mgr.upload(mgr.get_rse_info(self.rse_id), [{'name': f, 'scope': 'user.%s' % self.user}, ])
+        for fichier in MgrTestCases.files_remote:
+            mgr.upload(mgr.get_rse_info(self.rse_id), [{'name': fichier, 'scope': 'user.%s' % self.user}, ])
         self.mtc.test_delete_mgr_ok_single()
 
     # MGR-Tests: EXISTS
